@@ -1,6 +1,6 @@
 #!/usr/local/bin/python2.7
 ###############################################################################
-# $Id: gdal_merge.py 20778 2010-10-06 17:31:34Z rouault $
+# $Id: gdal_merge.py 24065 2012-03-04 00:35:26Z warmerdam $
 #
 # Project:  InSAR Peppers
 # Purpose:  Module to extract data from many rasters into one output.
@@ -24,6 +24,11 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 ###############################################################################
+# changes 29Apr2011
+# if the input image is a multi-band one, use all 
+# the channels in building the stack
+# anssi.pekkarinen@fao.org
+
 
 try:
     from osgeo import gdal
@@ -37,7 +42,6 @@ except:
 
 
 import sys
-import glob
 import math
 
 __version__ = '$id$'[5:-1]
@@ -65,7 +69,7 @@ def raster_copy( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
     t_band = t_fh.GetRasterBand( t_band_n )
 
     data = s_band.ReadRaster( s_xoff, s_yoff, s_xsize, s_ysize,
-                              t_xsize, t_ysize, t_band.DataType )
+                             t_xsize, t_ysize, t_band.DataType )
     t_band.WriteRaster( t_xoff, t_yoff, t_xsize, t_ysize,
                         data, t_xsize, t_ysize, t_band.DataType )
         
@@ -95,7 +99,7 @@ def raster_copy_with_nodata( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
 
     nodata_test = Numeric.equal(data_src,nodata)
     to_write = Numeric.choose( nodata_test, (data_src, data_dst) )
-                               
+
     t_band.WriteArray( to_write, t_xoff, t_yoff )
 
     return 0
@@ -241,7 +245,8 @@ class file_info:
 def Usage():
     print('Usage: gdal_merge.py [-o out_filename] [-of out_format] [-co NAME=VALUE]*')
     print('                     [-ps pixelsize_x pixelsize_y] [-tap] [-separate] [-q] [-v] [-pct]')
-    print('                     [-ul_lr ulx uly lrx lry] [-n nodata_value] [-init "value [value...]"]')
+    print('                     [-ul_lr ulx uly lrx lry] [-init "value [value...]"]')
+    print('                     [-n nodata_value] [-a_nodata output_nodata_value]')
     print('                     [-ot datatype] [-createonly] input_files')
     print('                     [--help-general]')
     print('')
@@ -265,6 +270,7 @@ def main( argv=None ):
     separate = 0
     copy_pct = 0
     nodata = None
+    a_nodata = None
     create_options = []
     pre_init = []
     band_type = None
@@ -322,6 +328,10 @@ def main( argv=None ):
             i = i + 1
             nodata = float(argv[i])
 
+        elif arg == '-a_nodata':
+            i = i + 1
+            a_nodata = float(argv[i])
+
         elif arg == '-f':
             # for backward compatibility.
             i = i + 1
@@ -356,11 +366,8 @@ def main( argv=None ):
             sys.exit( 1 )
 
         else:
-            # Expand any possible wildcards from command line arguments
-            f = glob.glob( arg )
-            if len(f) == 0:
-                print('File not found: "%s"' % (str( arg )))
-            names += f # append 1 or more files
+            names.append(arg)
+
         i = i + 1
 
     if len(names) == 0:
@@ -419,11 +426,16 @@ def main( argv=None ):
         xsize = int((lrx - ulx) / geotransform[1] + 0.5)
         ysize = int((lry - uly) / geotransform[5] + 0.5)
 
+
         if separate != 0:
-            bands = len(file_infos)
+            bands=0
+
+            for fi in file_infos:
+                bands=bands + fi.bands
         else:
             bands = file_infos[0].bands
 
+
         t_fh = Driver.Create( out_file, xsize, ysize, bands,
                               band_type, create_options )
         if t_fh is None:
@@ -437,13 +449,20 @@ def main( argv=None ):
             t_fh.GetRasterBand(1).SetRasterColorTable(file_infos[0].ct)
     else:
         if separate != 0:
-            bands = len(file_infos)
+            bands=0
+            for fi in file_infos:
+                bands=bands + fi.bands            
             if t_fh.RasterCount < bands :
-                print('Existing output file has less bands than the number of input files. You should delete it before. Terminating gdal_merge.')
+                print('Existing output file has less bands than the input files. You should delete it before. Terminating gdal_merge.')
                 sys.exit( 1 )
         else:
             bands = min(file_infos[0].bands,t_fh.RasterCount)
 
+    # Do we need to set nodata value ?
+    if a_nodata is not None:
+        for i in range(t_fh.RasterCount):
+            t_fh.GetRasterBand(i+1).SetNoDataValue(a_nodata)
+
     # Do we need to pre-initialize the whole mosaic file to some value?
     if pre_init is not None:
         if t_fh.RasterCount <= len(pre_init):
@@ -475,8 +494,9 @@ def main( argv=None ):
             for band in range(1, bands+1):
                 fi.copy_into( t_fh, band, band, nodata )
         else:
-            fi.copy_into( t_fh, 1, t_band, nodata )
-            t_band = t_band+1
+            for band in range(1, fi.bands+1):
+                fi.copy_into( t_fh, band, t_band, nodata )
+                t_band = t_band+1
             
         fi_processed = fi_processed+1
         if quiet == 0 and verbose == 0:
