@@ -1,6 +1,6 @@
 #!/usr/local/bin/python2.7
 #******************************************************************************
-#  $Id: gdal_proximity.py 19392 2010-04-12 18:27:09Z rouault $
+#  $Id: gdal_proximity.py 23152 2011-10-01 13:39:52Z rouault $
 # 
 #  Name:     gdalproximity
 #  Project:  GDAL Python Interface
@@ -160,7 +160,7 @@ if dst_ds is None:
     drv = gdal.GetDriverByName(format)
     dst_ds = drv.Create( dst_filename,
                          src_ds.RasterXSize, src_ds.RasterYSize, 1,
-                         gdal.GetDataTypeByName(creation_type) )
+                         gdal.GetDataTypeByName(creation_type), creation_options )
 
     dst_ds.SetGeoTransform( src_ds.GetGeoTransform() )
     dst_ds.SetProjection( src_ds.GetProjectionRef() )
